const superagent = require('superagent');

const drgs = {
    // to run locally, create a file in /cucumber called ".drg-credentials"
    // put in some valid drg credentials with theses two lines:
    // DRG_USER=something
    // DRG_PASSWORD=secret

    // the ".drg-credentials"-file is ignored by Git - we don't want to share the secret passwords!
    // p.s. it is also used further below, for DTG, as they share credentials
    nsp: {
        endpoint: 'https://testkald.nspop.dk/drg/api/execute',
        username: process.env.DRG_USER,
        password: process.env.DRG_PASSWORD,
    },
    intern: {
        endpoint: 'http://docker.intern.arosii.com:8081/drg/api/execute',
        username: 'test',
        password: 'test',
    },
};
const _drg = drgs[process.env['DRG']] || drgs.nsp;
const drgAgent = superagent
    .agent()
    .auth(_drg.username, _drg.password)
    .accept('application/json');
const drg = function () {
    return drgAgent.post(_drg.endpoint);
};
async function drgWithAttach(attach, body) {
    let response;
    try {
        response = await drg().send(body);
        if (response.body.code != 200) {
            attach(
                JSON.stringify(
                    response.body.response.main.Envelope.Body,
                    null,
                    2
                ),
                'application/json'
            );
        }
    } catch (err) {
        attach(JSON.stringify(err, null, 2), 'application/json');
        throw err;
    }
    return response;
}
const env = process.env.ENV || 'test1 cNSP';
const env_nas = process.env.ENV_NAS || 'test1 dNSP';
const patient_cpr = process.env.PATIENT_CPR;
const number_of_relatives = process.env.NUMBER_OF_RELATIVES;

const _dtg = {
    endpoint: 'https://stamdata.nspop.dk/dtg-webservice/',
    username: process.env.DRG_USER,
    password: process.env.DRG_PASSWORD,
};
const dtgAgent = superagent
    .agent()
    .auth(_dtg.username, _dtg.password)
    .accept('application/json');
const dtg = function (url) {
    return dtgAgent.post(_dtg.endpoint + url);
};
async function dtgWithAttach(attach, url, body) {
    let response;
    try {
        response = await dtg(url).send(body);
    } catch (err) {
        attach(JSON.stringify(err, null, 2), 'application/json');
        throw err;
    }
    return response;
}

module.exports = {
    drg,
    dtg,
    env,
    env_nas,
    patient_cpr,
    number_of_relatives,
    drgWithAttach,
    dtgWithAttach,
};
